pub fn inlay_hints(doc: &DocumentState, range: Range) -> Vec<InlayHint>Expand description
Handle inlay hints request.
Shows type annotations for variables declared without explicit types.
pub fn inlay_hints(doc: &DocumentState, range: Range) -> Vec<InlayHint>Handle inlay hints request.
Shows type annotations for variables declared without explicit types.